pub enum EpeeError {
InternalError,
InvalidHeader,
InvalidVersion(Option<u8>),
Short(usize),
UnrecognizedType,
EmptyKey,
DepthLimitExceeded,
TypeError,
EpeeReuse,
}Expand description
An error incurred when decoding.
Variants
InternalError
An unexpected state was reached while decoding.
InvalidHeader
The blob did not have the expected header.
InvalidVersion(Option<u8>)
The blob did not have the expected version.
For EpeeError::InvalidVersion(version), version is the version read from the blob.
Short(usize)
The blob was short, as discovered when trying to read {0} bytes.
UnrecognizedType
Unrecognized type specified.
EmptyKey
An object defined a key of "".
DepthLimitExceeded
The depth limit was exceeded.
TypeError
An operation expected one type yet the actual type was distinct.
EpeeReuse
An Epee object was reused.