ArrayIterator

Struct ArrayIterator 

pub struct ArrayIterator<'encoding, 'parent, B: BytesLike<'encoding>> {
    pub(crate) root: &'parent mut Epee<'encoding, B>,
    pub(crate) kind: Type,
    pub(crate) len: usize,
}
An iterator over an array.

Fields

root: &'parent mut Epee<'encoding, B>kind: Typelen: usize

Implementations

Source

impl<'encoding, 'parent, B: BytesLike<'encoding>> ArrayIterator<'encoding, 'parent, B>

pub fn next(&mut self) -> Option<Result<EpeeEntry<'encoding, '_, B>, EpeeError>>

The next item within the array.

This is approximate to Iterator::next yet each item maintains a mutable reference to the iterator. Accordingly, we cannot use Iterator::next which requires items not borrow from the iterator.

polonius-the-crab details a frequent limitation of Rust’s borrow checker which users of this function may incur. It also details potential solutions (primarily using inlined code instead of functions, callbacks) before presenting itself as a complete solution. Please refer to it if you have difficulties calling this method for context.