Epee

Struct Epee 

pub struct Epee<'encoding, B: BytesLike<'encoding>> {
    pub(crate) current_encoding_state: B,
    pub(crate) stack: Stack,
    pub(crate) error: Option<EpeeError>,
    pub(crate) _encoding_lifetime: PhantomData<&'encoding ()>,
}
A decoder for an EPEE-encoded object.

Fields

current_encoding_state: Bstack: Stackerror: Option<EpeeError>_encoding_lifetime: PhantomData<&'encoding ()>

Implementations

Source

impl<'encoding, B: BytesLike<'encoding>> Epee<'encoding, B>

pub fn new(encoding: B) -> Result<Self, EpeeError>

Create a new view of an encoding.

pub fn entry(&mut self) -> Result<EpeeEntry<'encoding, '_, B>, EpeeError>

Obtain an EpeeEntry representing the encoded object.

This takes a mutable reference as Epee is the owned object representing the decoder’s state. However, this is not eligible to be called again after consumption. Multiple calls to this function will cause an error to be returned.